@@ -348,3 +348,17 @@ void PuntateMain::on_stream22_clicked()
     process.start("sh /opt/serviziopubblico/script/p22.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down23_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d23.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream23_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p23.sh");
+    process.waitForFinished();
+}
